package com.yiboshi.science.param.dto;

import com.alibaba.excel.annotation.ExcelProperty;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.yiboshi.science.base.BaseDTO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.hibernate.validator.constraints.Length;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

@Data
@EqualsAndHashCode(callSuper=true)
@ApiModel(description = "专家项目分配表DTO")
public class ComProjectAssignDTO extends BaseDTO {
    /** 专家Id */
    @ApiModelProperty(value = "专家Id", position = 1)
    @Length(max=36, message = "专家Id不能大于36")
    private String expertId;
    /** 项目Id */
    @ApiModelProperty(value = "项目Id", position = 2)
    @Length(max=36, message = "项目Id不能大于36")
    private String projId;
    /** 分配年度 */
    @ApiModelProperty(value = "分配年度", position = 3)
    private Integer assignYear;
    /** 立项依据 */
    @ApiModelProperty(value = "立项依据", position = 4)
    private BigDecimal projectBasis;
    /** 项目研究的学术价值 */
    @ApiModelProperty(value = "项目研究的学术价值", position = 5)
    private BigDecimal academicValue;
    /** 创新性与科学意义 */
    @ApiModelProperty(value = "创新性与科学意义", position = 6)
    private BigDecimal innovation;
    /** 研究方案 */
    @ApiModelProperty(value = "研究方案", position = 7)
    private BigDecimal researchPlan;
    /** 预期结果 */
    @ApiModelProperty(value = "预期结果", position = 8)
    private BigDecimal expectedResults;
    /** 总分 */
    @ApiModelProperty(value = "总分", position = 9)
    private BigDecimal totalScore;
    /** 备注 */
    @ApiModelProperty(value = "备注", position =10)
    @Length(max=65535, message = "备注不能大于65535")
    private String remark;
    /** 审核状态（0 未评审 1 保存 2 已提交） */
    @ApiModelProperty(value = "审核状态（0 未评审 1 已评审）", position = 11)
    private Integer auditState;

    /** 评审状态 */
    private String stateName;
    /** 证件号 */
    @ExcelProperty("证件号")
    @ApiModelProperty(value = "证件号", position = 1)
    private String certId;
    /** 姓名 */
    @ExcelProperty("姓名")
    @ApiModelProperty(value = "姓名", position = 3)
    private String personName;
    /** 性别 */
    @ExcelProperty("性别")
    @ApiModelProperty(value = "性别", position = 4)
    private String sex;
    /** 出生日期 */
    @ApiModelProperty(value = "出生日期", position = 5)
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date birthday;
    /** 职称 */
    @ApiModelProperty(value = "职称", position = 7)
    private String title;
    /** 职称 */
    @ExcelProperty("职称")
    @ApiModelProperty(value = "职称", position = 15)
    private String titleName;
    /** 学位 */
    @ApiModelProperty(value = "学位", position = 8 )
    private String degree;
    /** 学位 */
    @ApiModelProperty(value = "学位", position = 8)
    private String degreeName;
    /** 邮箱 */
    @ApiModelProperty(value = "邮箱", position = 9)
    private String email;
    /** 电话号码 */
    @ApiModelProperty(value = "电话号码", position = 10)
    private String mobile;
    /** 单位 */
    @ApiModelProperty(value = "单位", position = 13)
    private String unitName;
    /** 工作单位 */
    @ApiModelProperty(value = "工作单位", position = 13)
    private String workUnit;
    /** 用户名 */
    @ApiModelProperty(value = "用户名", position = 13)
    private String username;
    /** 项目名称 */
    @ApiModelProperty(value = "项目名称", position = 1 )
    private String projName;
    /** 项目编号 */
    @ApiModelProperty(value = "项目编号", position = 2 )
    private String projNo;
    /** 项目类型  1 科研项目  2重点学科项目 */
    @ApiModelProperty(value = "项目名称", position = 1 )
    private Integer projType;
    /** 评审专业 */
    @ApiModelProperty(value = "评审专业", position = 13)
    private List<ComExpertSpecDTO> specList;
}
